"use strict";

const MODE_MARKDOWN = 0, MODE_MARKDOWN_SINGLE = 1, MODE_HTML = 2;

let scope = '';
let mode = MODE_MARKDOWN;
let inPath = '';
let outPath = 'out';
let codelang = 'scala';
let filterScope = x => true;
let useHeader = true;
let useFooter = true;

const args = process.argv.slice(2);
for (let i = 0; i < args.length; i++) {
    switch (args[i]) {
        case '--out':
        case '-o':
            if (i + 1 >= args.length)
                continue;
            i++;
            outPath = args[i];
            break;
            
        case '--input':
        case '-i':
            if (i + 1 >= args.length)
                continue;
            i++;
            inPath = args[i];
            break;
            
        case '--scope':
        case '-s':
            if (i + 1 >= args.length)
                continue;
            i++;
            scope = args[i];
            filterScope = (x => x.scope.toLowerCase() === 'both' || x.scope.toLowerCase() === scope);
            break;
            
        case '--mode':
        case '-m':
            if (i + 1 >= args.length)
                continue;
            i++;
            switch (args[i].toLowerCase()) {
                case 'html':
                    mode = MODE_HTML;
                    break;
                
                case 'markdown':
                case 'md':
                    mode = MODE_MARKDOWN;
                    break;
                
                default:
                    mode = MODE_MARKDOWN_SINGLE;
            }
            break;
        
        case '--code':
        case '-c':
            if (i + 1 >= args.length)
                continue;
            i++;
            codelang = args[i];
            break;
            
        case '--no-header':
        case '-nh':
            useHeader = false;
            break;
        
        case '--no-footer':
        case '-nf':
            useFooter = false;
            break;
    }
}

module.exports = {
    MODE_MARKDOWN, MODE_MARKDOWN_SINGLE, MODE_HTML,
    inPath, outPath,
    scope, mode, codelang, filterScope,
    useHeader, useFooter
};